2.0.10 (2025-01-18)
~~~~~~~~~~~~~~~~~~~

* [IMP] Minor improvements
* [IMP] Python 3.10

2.0.9 (2024-07-10)
~~~~~~~~~~~~~~~~~~

* [IMP] It does no more depends on os0
* [IMP] Python 3.6 deprecated

2.0.8 (2023-12-01)
~~~~~~~~~~~~~~~~~~

* [IMP] Translation excel file names


2.0.7 (2023-11-17)
~~~~~~~~~~~~~~~~~~

* [IMP] Automatic python version for Odoo

2.0.6 (2023-07-10)
~~~~~~~~~~~~~~~~~~

* [FIX] travis: check for dropped DB and abort if still exist
* [IMP] travis: action show as alias of show-log for please integration

2.0.5 (2023-05-14)
~~~~~~~~~~~~~~~~~~

* [IMP] New -p parameter to select specific test to execute
* [IMP] Switch -M removed
* [IMP] Switch -d set default "test" action
* [IMP] Removes osx support

2.0.4 (2023-03-24)
~~~~~~~~~~~~~~~~~~

* [IMP] Added python 3.9 to test
* [IMP] Detect python versions from setup.py
* [IMP] Option switch for python version become -j
* [IMP} make_travis recognizes verbose option

2.0.3 (2022-12-09)
~~~~~~~~~~~~~~~~~~

* [FIX] Best python version recognition

2.0.2.2 (2022-11-08)
~~~~~~~~~~~~~~~~~~~~

* [IMP] npm management

2.0.2.1 (2022-11-02)
~~~~~~~~~~~~~~~~~~~~

* [REF] travis: partial refactoring
* [IMP] travis: recognition of local/librerp

2.0.2 (2022-10-20)
~~~~~~~~~~~~~~~~~~

* [IMP] database name: (test|template)_odoo
* [IMP] With -k switch set ODOO_COMMIT_TEST

2.0.1.1 (2022-10-12)
~~~~~~~~~~~~~~~~~~~~

* [IMP] travis: change logfile name

2.0.1 (2022-10-12)
~~~~~~~~~~~~~~~~~~

* [IMP] stable version

2.0.0.2 (2022-10-04)
~~~~~~~~~~~~~~~~~~~~

* [IMP] travis: python2 tests


2.0.0.1 (2022-09-06)
~~~~~~~~~~~~~~~~~~~~

* [IMP] travis: new improvements (-f -k switches)


2.0.0 (2022-08-10)
~~~~~~~~~~~~~~~~~~

* [REF] Partial refactoring for shell scripts

